==> 1.0.32.tar.gz: example/lib/ble/view/ble_page.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_cardioclick/'
    'healthrian_ble_support_for_cardioclick.dart';

class BlePage extends StatelessWidget {
  const BlePage({super.key});

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.tapButtonStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.leadStateStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.connectionStateStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.heartRateStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.bufferedPlotRTStreamEcg,
                  builder: (context, snapshot) {
                    log('${snapshot.data?.l2.length}');
                    return Text('${snapshot.data?.l2.length}');
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().connectDevice();
                await BLEManager().registerCharacteristics();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().disconnectDevice();
              },
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().startMeasurementEcg();
              },
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().pauseMeasurementEcg();
              },
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().stopMeasurementEcg();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}

==> 1.1.6.tar.gz: example/lib/ble/view/ble_page.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_cardioclick/'
    'healthrian_ble_support_for_cardioclick.dart';

class BlePage extends StatelessWidget {
  const BlePage({super.key});

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManagerV2().streams.tapButtonStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManagerV2().streams.leadStateStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManagerV2().streams.connectionStateStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManagerV2().streams.heartRateStream,
                  builder: (context, snapshot) {
                    log('${snapshot.data}');
                    return Text('${snapshot.data}');
                  },
                );
              },
            ),
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManagerV2().streams.bufferedPlotRTStreamEcg,
                  builder: (context, snapshot) {
                    log('${snapshot.data?.l2.length}');
                    return Text('${snapshot.data?.l2.length}');
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            FloatingActionButton(
              onPressed: () async {
                await BLEManagerV2().connectDevice();
                await BLEManagerV2().registerCharacteristics();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManagerV2().disconnectDevice();
              },
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManagerV2().startMeasurementEcg();
              },
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManagerV2().pauseMeasurementEcg();
              },
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManagerV2().stopMeasurementEcg();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}
